
from setuptools import setup

setup(package_data={'gdb-stubs': ['FrameDecorator.pyi', 'FrameIterator.pyi', '__init__.pyi', 'dap/__init__.pyi', 'dap/breakpoint.pyi', 'dap/bt.pyi', 'dap/disassemble.pyi', 'dap/evaluate.pyi', 'dap/events.pyi', 'dap/frames.pyi', 'dap/io.pyi', 'dap/launch.pyi', 'dap/locations.pyi', 'dap/memory.pyi', 'dap/modules.pyi', 'dap/next.pyi', 'dap/pause.pyi', 'dap/scopes.pyi', 'dap/server.pyi', 'dap/sources.pyi', 'dap/startup.pyi', 'dap/state.pyi', 'dap/threads.pyi', 'dap/typecheck.pyi', 'dap/varref.pyi', 'disassembler.pyi', 'events.pyi', 'missing_debug.pyi', 'missing_files.pyi', 'missing_objfile.pyi', 'printing.pyi', 'prompt.pyi', 'types.pyi', 'unwinder.pyi', 'xmethod.pyi', 'METADATA.toml', 'py.typed']})
